@@ -76,9 +76,9 @@ def get_current_user_data(security_scopes: SecurityScopes, token: str = Depends(
         data_token.name = payload.get("name")
         data_token.username = payload.get("username")
         data_token.email = payload.get("email")
-        data_token.school_id = str(payload.get("school_id"))
-        data_token.ppdb_id = str(payload.get("ppdb_id"))
-        data_token.user_id = str(payload.get("user_id"))
+        data_token.school_id = payload.get("school_id")
+        data_token.ppdb_id = payload.get("ppdb_id")
+        data_token.user_id = payload.get("user_id")
         data_token.role = payload.get("role")
         data_token.exp = payload.get("exp")
         if str(security_scopes.scopes[0]).lower() == "*":
@@ -103,9 +103,9 @@ async def create_refresh_token(response, token):
         data_token.name = payload.get("name")
         data_token.username = payload.get("username")
         data_token.email = payload.get("email")
-        data_token.school_id = str(payload.get("school_id"))
-        data_token.ppdb_id = str(payload.get("ppdb_id"))
-        data_token.user_id = str(payload.get("user_id"))
+        data_token.school_id = payload.get("school_id")
+        data_token.ppdb_id = payload.get("ppdb_id")
+        data_token.user_id = payload.get("user_id")
         data_token.role = payload.get("role")
 
         # cek token sekarang masih on atau gak
